.noborder {
	border:none;
}
.textHead{
    text-shadow: 2px 2px @theme_bg_color;
	color: @theme_text_color;
}
.thin {
	margin:0px;
	padding:0px;
}
.inherited>* {
	border:none;
	background:inherit;
}
.opacited {
	opacity:0.98;
}
.borders {
border-radius: 2px;
border-width: 1px;
border-color: @theme_text_color;
}
.workingbg {
	background:@theme_base_color;
}
.textoutline {
	text-shadow: 0.5px 0 0.5px @theme_bg_color, 
0 0.5px 0.5px @theme_bg_color, 
-0.5px 0 0.5px @theme_bg_color, 
0 -0.5px 0.5px @theme_bg_color;
}
.nobackground {
	background: none;
}
.menuitembottom{
	margin-top:0px;
	margin-bottom:3px;
	border-color:inherit;
	border-left-width:inherit;
	border-right-width:inherit;
  }
  .menuitemmiddle{
	margin-top:0px;
	margin-bottom:0px;
	border-color:inherit;
	border-left-width:inherit;
	border-right-width:inherit;
  }
  
  .menuitemtop{
	margin-bottom:0px;
	border-color:inherit;
	border-top-width:inherit;
	border-left-width:inherit;
	border-right-width:inherit;
  }
  .menuitemtop *{
	margin:2px 2px 0 2px;
	padding: 5px 10px 3px 5px;
	border:transparent;
  }
  .menuitemmiddle *{
	margin:0 2px 0 2px;
	padding: 3px 10px 3px 5px;
	border:transparent;
  }
  .menuitembottom *{
	margin:0 2px 2px 2px;
	padding: 3px 10px 5px 5px;
  }
  .menuitemtop:hover {
	background:@theme_bg_color;
	border-color:inherit;
	border-top-width:inherit;
	border-left-width:inherit;
	border-right-width:inherit;
  }
  .menuitemmiddle:hover {
	background:@theme_bg_color;
	border-color:inherit;
	border-left-width:inherit;
	border-right-width:inherit;
  }
  .menuitembottom:hover {
	background:@theme_bg_color;
	border-color:inherit;
	border-bottom-width:0px;
	border-left-width:inherit;
	border-right-width:inherit;
	
  }
  .menuitemtop:hover* {
	margin:2px 2px 0 2px;
	padding: 5px 10px 3px 5px;
	background:@theme_selected_bg_color;
	border-radius:2px;
  }
  .menuitemmiddle:hover* {
	margin:0 2px 0 2px;
	padding: 3px 10px 3px 5px;
	background:@theme_selected_bg_color;
	border-radius:2px;
  }
  .menuitembottom:hover* {
	margin:0 2px 2px 2px;
	padding: 3px 10px 5px 5px;
	background:@theme_selected_bg_color;
	border-radius:2px;
  }

  .boxInfoMessError{
    background-color: #ea9999;
}

.boxInfoMessOK{
    background-color: #f3f0ac;
}